;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "solarized-theme" "20250913.451"
  "The Solarized color theme."
  '((emacs "24.1"))
  :url "http://github.com/bbatsov/solarized-emacs"
  :commit "65f6772119462f2e91a9d70f0c4e1085bddd29c9"
  :revdesc "65f677211946"
  :keywords '("convenience" "themes" "solarized")
  :authors '(("Bozhidar Batsov" . "bozhidar@batsov.dev"))
  :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
